#!/usr/bin/python3

#	control++ : System configuration tool
#	Copyright (C) 2017-2021 Alexey Appolonov
#
#	This program is free software: you can redistribute it and/or modify
#	it under the terms of the GNU General Public License as published by
#	the Free Software Foundation, either version 3 of the License, or
#	(at your option) any later version.
#
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with this program.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #

import os
import stat

# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
# Decorator function that catches the exceptions raised in a passed function

def CatchExc(func):

	def Wrapper(self=None):
		try:
			func(self)
		except Exception as e:
			print(str(e))
			return False
		return True

	return Wrapper

# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
# Namespace containing string constants initialized with the "debug" flag

class Const():

	def __init__(self, debug=False):

		# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
		# Basic constants

		self.__TESTED_EXE = ('../bin/' if debug else '') + 'control++'
		self.CONF_DIR     = '../samples' if debug else '/etc/control++'
		self.__UNIT_PERM  = 'permissions'
		self.__UNIT_ULIM  = 'ulimits'
		self.__UNIT_STRT  = 'scripts'
		self.__MODE_SETTING = {el: [self.__TESTED_EXE, el] for el in
			(self.__UNIT_PERM, self.__UNIT_ULIM, self.__UNIT_STRT)}
		self.PERM_MODE_SETTING = self.__MODE_SETTING[self.__UNIT_PERM]
		self.ULIM_MODE_SETTING = self.__MODE_SETTING[self.__UNIT_ULIM]
		self.STRT_MODE_SETTING = self.__MODE_SETTING[self.__UNIT_STRT]
		self.__SUBMODE_DESC = {el: os.path.join(self.CONF_DIR, el) for el in
			(self.__UNIT_PERM,  self.__UNIT_ULIM, self.__UNIT_STRT)}
		self.UNIT_PERM_DESC = self.__SUBMODE_DESC[self.__UNIT_PERM]
		self.UNIT_ULIM_DESC = self.__SUBMODE_DESC[self.__UNIT_ULIM]
		self.UNIT_STRT_DESC = self.__SUBMODE_DESC[self.__UNIT_STRT]
		self.EXEC_BITS = (stat.S_IXUSR | stat.S_IXGRP | stat.S_IXOTH)

		# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
		# Test dirrectory

		# 	[test_dir]:
		#		[base_dir]:
		#			[d1]:
		#				[d1]:
		#					f1, f2
		#				f1, f2
		#			[d1]:
		#				f1, f2
		#			[d3]
		#			f1, f2
		#		[d1]:
		#			f1
		#		[d2]:
		#			f1
		#		f1

		self.EXEC_DIR = '.' if debug else \
			os.path.join('/var/lib', self.__TESTED_EXE + '/tests')
		self.TEST_DIR = 'test_dir' if debug else \
			os.path.join('/run', self.__TESTED_EXE)
		self.BASE_DIR = os.path.join(self.TEST_DIR, 'base_dir')
		self.INSIDE_FILES = \
			[os.path.join(self.BASE_DIR, os.path.join(d, f) if f else d)
				for d in ('d1', 'd1/d1', 'd2', '')
				for f in ('', 'f1', 'f2') if f or d] + \
			[os.path.join(self.BASE_DIR, 'd3')]
		self.OUTSIDE_FILES = \
			[os.path.join(self.TEST_DIR, os.path.join(d, f) if f else d)
				for d in ('d1', 'd2', '')
				for f in ('', 'f1') if f or d]
		self.TEST_FILES = self.INSIDE_FILES + self.OUTSIDE_FILES + \
			[self.BASE_DIR]
		self.REG_FILES = [f for f in self.TEST_FILES if f[-2] == 'f']
		self.DIR_FILES = [f for f in self.TEST_FILES if f[-2] != 'f']
		self.__TEST_FILES_ODD  = [f for f in self.TEST_FILES
			if os.path.basename(f) != 'base_dir' and int(f[-1]) % 2 == 1]
		self.REG_FILES_ODD = [f for f in self.__TEST_FILES_ODD
			if f in self.REG_FILES]
		self.DIR_FILES_ODD = [f for f in self.__TEST_FILES_ODD
			if f in self.DIR_FILES]
