#!/usr/bin/python3

#	control++ : System configuration tool
#	Copyright (C) 2017-2021 Alexey Appolonov
#
#	This program is free software: you can redistribute it and/or modify
#	it under the terms of the GNU General Public License as published by
#	the Free Software Foundation, either version 3 of the License, or
#	(at your option) any later version.
#
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with this program.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #

import os
from collections import defaultdict
from common      import CatchExc

# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
# Mode description

class ModeDesc():

	def __init__(self, path, unit_perm_desc):

		self.sections = []
		self.current_sec = ''
		self.path = path
		self.unit_perm_desc = unit_perm_desc

	# # # # # # # # # # # # # # # # # # # # # # # # # # # # # #

	def __Stringify(self):

		s = ''

		for sec in self.sections:
			for sec_name, fields in sec.items():
				s = f'[{sec_name}]\n' + '\n'.join(fields)

		return s

	# # # # # # # # # # # # # # # # # # # # # # # # # # # # # #

	def NewSec(self, sec_name):

		self.sections.append(defaultdict(list))
		self.current_sec = sec_name

	# # # # # # # # # # # # # # # # # # # # # # # # # # # # # #

	def AddField(self, field):

		if self.current_sec:
			self.sections[-1][self.current_sec].append(field)

	# # # # # # # # # # # # # # # # # # # # # # # # # # # # # #

	@CatchExc
	def Write(self):

		with open(self.path, 'w') as f:
			f.write(self.__Stringify())

	# # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
	# Clear every mode description used during testing

	@CatchExc
	def Clear(self):

		lists = [os.path.join(self.unit_perm_desc, f'test_{l}list')
			for l in ('black', 'white')]

		for path in lists + [self.path]:
			if os.path.isfile(path):
				os.remove(path)
